==> SWMM5-1.0.0.1.zip: SWMM5-1.0.0.1/swmm5/swmm5/keywords.h <==
//-----------------------------------------------------------------------------
//   keywords.h
//
//   Project: EPA SWMM5
//   Version: 5.0
//   Date:    6/19/07   (Build 5.0.010)
//            2/4/08    (Build 5.0.012)
//            1/21/09   (Build 5.0.014)
//            4/10/09   (Build 5.0.015)
//   Author:  L. Rossman
//
//   Exportable keyword dictionary
//-----------------------------------------------------------------------------

extern char* FileTypeWords[];
extern char* FileModeWords[];
extern char* BuildupTypeWords[];
extern char* NormalizerWords[];
extern char* WashoffTypeWords[];
extern char* TreatTypeWords[];
extern char* ProcessVarWords[];
extern char* PatternTypeWords[];
extern char* CurveTypeWords[];
extern char* RuleKeyWords[];
extern char* ReportWords[];
extern char* NoYesWords[];
extern char* NoneAllWords[];
extern char* QualUnitsWords[];
extern char* TempKeyWords[];
extern char* EvapTypeWords[];
extern char* SnowmeltWords[];
extern char* GageDataWords[];
extern char* RainTypeWords[];
extern char* RainUnitsWords[];
extern char* OffOnWords[];
extern char* DividerTypeWords[];
extern char* OutfallTypeWords[];
extern char* OrificeTypeWords[];
extern char* WeirTypeWords[];
extern char* NormalFlowWords[];                                                //(5.0.010 - LR)
extern char* RelationWords[];
extern char* OptionWords[];
extern char* FlowUnitWords[];
extern char* ForceMainEqnWords[];                                              //(5.0.010 - LR)
extern char* LinkOffsetWords[];                                                //(5.0.012 - LR)
extern char* RouteModelWords[];
extern char* OldRouteModelWords[];
extern char* DynWaveMethodWords[];
extern char* InfilModelWords[];
extern char* InertDampingWords[];
extern char* TransectKeyWords[];
extern char* XsectTypeWords[];
extern char* SectWords[];

extern char* LoadUnitsWords[];                                                 //(5.0.012 - LR)
extern char* NodeTypeWords[];                                                  //(5.0.012 - LR)
extern char* LinkTypeWords[];                                                  //(5.0.012 - LR)
extern char* PumpTypeWords[];                                                  //(5.0.012 - LR)
extern char* VolUnitsWords[];                                                  //(5.0.012 - LR)
extern char* PondingUnitsWords[];                                              //(5.0.012 - LR)

extern char* UHTypeWords[];                                                    //(5.0.015 - LR)

==> SWMM5-1.1.0.1dev.zip: SWMM5-1.1.0.1dev/swmm5/swmm5/keywords.h <==
//-----------------------------------------------------------------------------
//   keywords.h
//
//   Project: EPA SWMM5
//   Version: 5.1
//   Date:    03/19/14   (Build 5.1.000)
//   Author:  L. Rossman
//
//   Exportable keyword dictionary
//-----------------------------------------------------------------------------

extern char* FileTypeWords[];
extern char* FileModeWords[];
extern char* BuildupTypeWords[];
extern char* NormalizerWords[];
extern char* WashoffTypeWords[];
extern char* TreatTypeWords[];
extern char* ProcessVarWords[];
extern char* PatternTypeWords[];
extern char* CurveTypeWords[];
extern char* RuleKeyWords[];
extern char* ReportWords[];
extern char* NoYesWords[];
extern char* NoneAllWords[];
extern char* QualUnitsWords[];
extern char* TempKeyWords[];
extern char* EvapTypeWords[];
extern char* SnowmeltWords[];
extern char* GageDataWords[];
extern char* RainTypeWords[];
extern char* RainUnitsWords[];
extern char* OffOnWords[];
extern char* DividerTypeWords[];
extern char* OutfallTypeWords[];
extern char* OrificeTypeWords[];
extern char* WeirTypeWords[];
extern char* NormalFlowWords[];
extern char* RelationWords[];
extern char* OptionWords[];
extern char* FlowUnitWords[];
extern char* ForceMainEqnWords[];
extern char* LinkOffsetWords[];
extern char* RouteModelWords[];
extern char* OldRouteModelWords[];
extern char* DynWaveMethodWords[];
extern char* InfilModelWords[];
extern char* InertDampingWords[];
extern char* TransectKeyWords[];
extern char* XsectTypeWords[];
extern char* SectWords[];
extern char* LoadUnitsWords[];
extern char* NodeTypeWords[];
extern char* LinkTypeWords[];
extern char* PumpTypeWords[];
extern char* VolUnitsWords[];
extern char* VolUnitsWords2[];
extern char* PondingUnitsWords[];
extern char* UHTypeWords[];
